* Appendix Table 5 - Beta Convergence Test by Endowment Type
* Also creates Appendix Figure 1 graphs. 

* --------------------
* Panel A: GDP Per Capita
* --------------------
use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear		
	
	replace gdp_pc7074 = ln(gdp_pc7074)
		label var gdp_pc7074 "Log Real GDP per Capita - 1970-1974"
	
	*Conditional Convergence Test - Oil Endowed Countries only. 
	preserve
		keep if oilendowed==1
		 
		reg  avggrowthrate_40yr  gdp_pc7074 , robust
		reg  avggrowthrate_40yr  gdp_pc7074 $controls , robust
				
		twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 	///
			(lfit avggrowthrate_40yr  gdp_pc7074), 													///
			title("Oil")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
		
		graph save "$dir/figures/temp/Conditional Convergence Test - Oil Endowed", replace
	restore	
	

	*Conditional Convergence Test - Natural Gas Endowed Countries only. 
	preserve
		keep if gasendowed==1
		
		reg  avggrowthrate_40yr  gdp_pc7074 , robust
		reg  avggrowthrate_40yr  gdp_pc7074 $controls , robust
					
		twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 	///
			(lfit avggrowthrate_40yr  gdp_pc7074), 													///
			title("Natural Gas")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
		
		graph save "$dir/figures/temp/Conditional Convergence Test - Gas Endowed", replace
	restore		
	
	*Conditional Convergence Test - Coal Endowed Countries only. 
	preserve
		keep if coalendowed==1
		
		reg avggrowthrate_40yr  gdp_pc7074 , robust
		reg avggrowthrate_40yr  gdp_pc7074 $controls , robust
					
		twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 	///
			(lfit avggrowthrate_40yr  gdp_pc7074), 													///
			title("Coal")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
			
		graph save "$dir/figures/temp/Conditional Convergence Test - Coal Endowed", replace
	restore				
	
	*Combine graphs
	graph combine "$dir/figures/temp/Conditional Convergence Test - Oil Endowed"					///
		"$dir/figures/temp/Conditional Convergence Test - Gas Endowed"					///
		"$dir/figures/temp/Conditional Convergence Test - Coal Endowed"				///
		, ycommon xcommon 													///
		l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Capita 1970-1975") 	///
		rows(1)   ysize(1.5)  xsize(4.5)
		
	graph export "$dir/figures/Appendix Figure 1a - Beta Convergence - GDP Per Capita.png", replace
	
	
* --------------------
* Panel B: Consumption Per Capita
* --------------------

	use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear			
	
	replace consumption_pc7074 = ln(consumption_pc7074)
		label var consumption_pc7074 "Log Real Consumption per Capita - 1970-1974"
	
	*Conditional Convergence Test - Oil Endowed Countries only. 
	preserve
		keep if oilendowed==1
		 
		reg cavggrowthrate_40yr  consumption_pc7074 , robust
		reg cavggrowthrate_40yr  consumption_pc7074 $controls , robust
		
		twoway (scatter cavggrowthrate_40yr  consumption_pc7074 ) 	///
			(lfit cavggrowthrate_40yr  consumption_pc7074), 													///
			title("Oil")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  )  legend(off)	 xlabel(, grid gmax)   xtitle("")
		
		graph save "$dir/figures/temp/Conditional Convergence Test - Consumption - Oil Endowed", replace
	restore	

	*Conditional Convergence Test - Natural Gas Endowed Countries only. 
	preserve
		keep if gasendowed==1
		
		reg  cavggrowthrate_40yr  consumption_pc7074 , robust
		reg cavggrowthrate_40yr  consumption_pc7074 $controls , robust
			
		twoway (scatter cavggrowthrate_40yr  consumption_pc7074 ) 	///
			(lfit cavggrowthrate_40yr  consumption_pc7074 ), 													///
			title("Natural Gas")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  )  legend(off)	 xlabel(, grid gmax)   xtitle("")
		
		graph save "$dir/figures/temp/Conditional Convergence Test - Consumption - Gas Endowed", replace
	restore		
	
	*Conditional Convergence Test - Coal Endowed Countries only. 
	preserve
		keep if coalendowed==1
		
		reg cavggrowthrate_40yr  consumption_pc7074 , robust
		reg cavggrowthrate_40yr  consumption_pc7074 $controls , robust
	
		twoway (scatter cavggrowthrate_40yr  consumption_pc7074 ) 	///
			(lfit cavggrowthrate_40yr  consumption_pc7074 ), 													///
			title("Coal")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
			
		graph save "$dir/figures/temp/Conditional Convergence Test - Consumption - Coal Endowed", replace
	restore			
		
	*Combine graphs	
		graph combine "$dir/figures/temp/Conditional Convergence Test - Oil Endowed"					///
			"$dir/figures/temp/Conditional Convergence Test - Consumption - Gas Endowed"					///
			"$dir/figures/temp/Conditional Convergence Test - Consumption - Coal Endowed"				///
			, ycommon xcommon 													///
			l1title("Average Annual Growth Rate")  b1title("Log Real Consumption Per Capita 1970-1975") 	///
			rows(1)   ysize(1.5)  xsize(4.5)	
	
	graph export "$dir/figures/Appendix Figure 1b - Beta Convergence - Consumption Per Capita.png", replace
	
	
	
	
