*---------------*
* Sigma Convergence Test
*---------------*

*---------------*
* GDP Per Capita
*---------------*
use "$dir/Oliver Upton - EJ 2022 - Panel.dta", clear

	preserve
		use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear
		keep countrycode
		gen finalsample = 1
		drop if countrycode==""
		tempfile finalsamplecountries
		save "`finalsamplecountries'"
	restore

	merge m:1 countrycode using "`finalsamplecountries'", nogen
	keep if finalsample==1
	drop finalsample
	
	xtset country_id year

	gen gdp_pc = rgdpo/pop
	replace gdp_pc = ln(gdp_pc)
		label var gdp_pc "Logged real GDP per Capita"
		
keep country year gdp_pc countrycode country_id coalendowed gasendowed oilendowed energyendowment oecd

sort year country

*FULL SAMPLE
preserve

egen stdev_full=sd(gdp_pc), by(year)
egen mean_full=mean(gdp_pc), by(year)

keep year stdev_full mean_full
duplicates drop year, force

gen coeff_var_full=stdev_full/mean_full

label var stdev_full "Standard Deviation"
label var coeff_var_full "Coefficient of Variation"

tempfile full
save "`full'"

tsset year
tsline coeff_var_full, title("{&sigma} convergence test: Full sample") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))

	graph export "$dir/figures/temp/Sigma Convergence/Full sample.png", replace

restore

*RESOURCE ENDOWED
preserve

keep if energyendowment==1

egen stdev_res=sd(gdp_pc), by(year)
egen mean_res=mean(gdp_pc), by(year)

keep year stdev_res mean_res
duplicates drop year, force

gen coeff_var_res=stdev_res/mean_res

label var stdev_res "Standard Deviation"
label var coeff_var_res "Coefficient of Variation"

tempfile resource
save "`resource'"

tsset year
tsline coeff_var_res, title("{&sigma} convergence test: Resource endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Energy Endowed.png", replace

restore

* NON-RESOURCE ENDOWED
preserve

keep if energyendowment==0

egen stdev_nores=sd(gdp_pc), by(year)
egen mean_nores=mean(gdp_pc), by(year)

keep year stdev_nores mean_nores
duplicates drop year, force

gen coeff_var_nores=stdev_nores/mean_nores

label var stdev_nores "Standard Deviation"
label var coeff_var_nores "Coefficient of Variation"

tempfile non_res
save "`non_res'"

tsset year
tsline coeff_var_nores, title("{&sigma} convergence test: Non-resource endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Non-Energy Endowed.png", replace

restore

* COAL ENDOWED
preserve

keep if coalendowed==1

egen stdev_coal=sd(gdp_pc), by(year)
egen mean_coal=mean(gdp_pc), by(year)

keep year stdev_coal mean_coal
duplicates drop year, force

gen coeff_var_coal=stdev_coal/mean_coal

label var stdev_coal "Standard Deviation"
label var coeff_var_coal "Coefficient of Variation"

tempfile coal
save "`coal'"

tsset year
tsline coeff_var_coal, title("{&sigma} convergence test: Coal endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Coal Endowed.png", replace

restore

* GAS ENDOWED
preserve

keep if gasendowed==1

egen stdev_gas=sd(gdp_pc), by(year)
egen mean_gas=mean(gdp_pc), by(year)

keep year stdev_gas mean_gas
duplicates drop year, force

gen coeff_var_gas=stdev_gas/mean_gas

label var stdev_gas "Standard Deviation"
label var coeff_var_gas "Coefficient of Variation"

tempfile gas
save "`gas'"

tsset year
tsline coeff_var_gas, title("{&sigma} convergence test: Gas endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Gas Endowed.png", replace

restore

* OIL ENDOWED
preserve

keep if oilendowed==1

egen stdev_oil=sd(gdp_pc), by(year)
egen mean_oil=mean(gdp_pc), by(year)

keep year stdev_oil mean_oil
duplicates drop year, force

gen coeff_var_oil=stdev_oil/mean_oil

label var stdev_oil "Standard Deviation"
label var coeff_var_oil "Coefficient of Variation"

tempfile oil
save "`oil'"

tsset year
tsline coeff_var_oil, title("{&sigma} convergence test: Oil endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Oil Endowed.png", replace

restore

* Combine Graphs - Resource Endowed vs. Non-Resource Endowed
use "`resource'", clear
merge 1:1 year using "`non_res'", nogen
merge 1:1 year using "`coal'", nogen
merge 1:1 year using "`gas'", nogen
merge 1:1 year using "`oil'", nogen

label var coeff_var_res "Energy Endowment"
label var coeff_var_nores "No Energy Endowment"
label var coeff_var_coal "Coal endowed"
label var coeff_var_gas "Gas endowed"
label var coeff_var_oil "Oil endowed"

tsset year
tsline coeff_var_res coeff_var_nores , title("GDP") ytitle(Coefficient of Variation) ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
	
		graph export "$dir/figures/temp/Sigma Convergence/Summary - All Resources.png", replace
		graph save "$dir/figures/temp/Sigma Convergence/Summary - All Resources", replace

tsline coeff_var_nores coeff_var_coal coeff_var_gas coeff_var_oil, title("GDP") ytitle(Coefficient of Variation)  ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
	
		graph export "$dir/figures/temp/Sigma Convergence/Summary - Resources by Type.png", replace
		graph save "$dir/figures/temp/Sigma Convergence/Summary - Resources by Type", replace

*---------------*
* Consumption Per Capita
*---------------*
use "$dir/Oliver Upton - EJ 2022 - Panel.dta", clear

	preserve
		use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear
		keep countrycode
		gen finalsample = 1
		drop if countrycode==""
		tempfile finalsamplecountries
		save "`finalsamplecountries'"
	restore

	merge m:1 countrycode using "`finalsamplecountries'", nogen
	keep if finalsample==1
	drop finalsample

xtset country_id year

	gen gdp_pc = rgdpo/pop
	replace gdp_pc = ln(rgdpo)
		label var gdp_pc "Logged real GDP per Capita"
		
	gen consumption_pc = ccon / pop
	replace consumption_pc = ln(consumption_pc)
		label var consumption_pc "Logged real Consumption per Capita"

keep country year gdp_pc consumption_pc countrycode country_id coalendowed gasendowed oilendowed energyendowment oecd
sort year country

*FULL SAMPLE
preserve

egen stdev_full=sd(consumption_pc), by(year)
egen mean_full=mean(consumption_pc), by(year)

keep year stdev_full mean_full
duplicates drop year, force

gen coeff_var_full=stdev_full/mean_full

label var stdev_full "Standard Deviation"
label var coeff_var_full "Coefficient of Variation"

tempfile full
save "`full'"

tsset year
tsline coeff_var_full, title("Consumption - Full sample") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))

	graph export "$dir/figures/temp/Sigma Convergence/Consumption - Full sample.png", replace

restore

* RESOURCE ENDOWED

preserve

keep if energyendowment==1

egen stdev_res=sd(consumption_pc), by(year)
egen mean_res=mean(consumption_pc), by(year)

keep year stdev_res mean_res
duplicates drop year, force

gen coeff_var_res=stdev_res/mean_res

label var stdev_res "Standard Deviation"
label var coeff_var_res "Coefficient of Variation"

tempfile resource
save "`resource'"

tsset year
tsline coeff_var_res, title("Consumption - Resource endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Consumption - Energy Endowed.png", replace

restore

* NON-RESOURCE ENDOWED

preserve

keep if energyendowment==0

egen stdev_nores=sd(consumption_pc), by(year)
egen mean_nores=mean(consumption_pc), by(year)

keep year stdev_nores mean_nores
duplicates drop year, force

gen coeff_var_nores=stdev_nores/mean_nores

label var stdev_nores "Standard Deviation"
label var coeff_var_nores "Coefficient of Variation"

tempfile non_res
save "`non_res'"

tsset year
tsline coeff_var_nores, title("Consumption - Non-resource endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Consumption - Non-Energy Endowed.png", replace

restore

		* COAL ENDOWED

		preserve
			keep if coalendowed==1
			egen stdev_coal=sd(consumption_pc), by(year)
			egen mean_coal=mean(consumption_pc), by(year)
			
			keep year stdev_coal mean_coal
			duplicates drop year, force
			
			gen coeff_var_coal=stdev_coal/mean_coal
			
			label var stdev_coal "Standard Deviation"
			label var coeff_var_coal "Coefficient of Variation"
			
			tempfile coal
			save "`coal'"
			
			tsset year
			tsline coeff_var_coal, title("Consumption - Coal endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
			graph export "$dir/figures/temp/Sigma Convergence/Consumption - Coal Endowed.png", replace
		restore

* GAS ENDOWED
preserve

keep if gasendowed==1

egen stdev_gas=sd(consumption_pc), by(year)
egen mean_gas=mean(consumption_pc), by(year)

keep year stdev_gas mean_gas
duplicates drop year, force

gen coeff_var_gas=stdev_gas/mean_gas

label var stdev_gas "Standard Deviation"
label var coeff_var_gas "Coefficient of Variation"

tempfile gas
save "`gas'"

tsset year
tsline coeff_var_gas, title("Consumption - Gas endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Consumption - Gas Endowed.png", replace

restore

*OIL ENDOWED
preserve

keep if oilendowed==1

egen stdev_oil=sd(consumption_pc), by(year)
egen mean_oil=mean(consumption_pc), by(year)

keep year stdev_oil mean_oil
duplicates drop year, force

gen coeff_var_oil=stdev_oil/mean_oil

label var stdev_oil "Standard Deviation"
label var coeff_var_oil "Coefficient of Variation"

tempfile oil
save "`oil'"

tsset year
tsline coeff_var_oil, title("Consumption - Oil endowed") ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
graph export "$dir/figures/temp/Sigma Convergence/Consumption - Oil Endowed.png", replace

restore

*Combined graph - Resource Endowed vs. Non-Resource Endowned - Consumption
use "`resource'", clear
merge 1:1 year using "`non_res'", nogen
merge 1:1 year using "`coal'", nogen
merge 1:1 year using "`gas'", nogen
merge 1:1 year using "`oil'", nogen

label var coeff_var_res "Energy Endowment"
label var coeff_var_nores "No Energy Endowment"
label var coeff_var_coal "Coal endowed"
label var coeff_var_gas "Gas endowed"
label var coeff_var_oil "Oil endowed"

tsset year
tsline coeff_var_res coeff_var_nores , title("Consumption") ytitle(Coefficient of Variation)  ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
	
graph save "$dir/figures/temp/Sigma Convergence/Summary - All Resources - Consumption", replace

tsline coeff_var_nores coeff_var_coal coeff_var_gas coeff_var_oil, title("Consumption") ytitle(Coefficient of Variation) ysize(2)  xsize(4.5) legend(size(vsmall) row(1))
	
graph export "$dir/figures/temp/Sigma Convergence/Summary - Resources by Type - Consumption.png", replace
graph save "$dir/figures/temp/Sigma Convergence/Summary - Resources by Type - Consumption", replace

*---------------*
* Combining Graphs - GDP and Consumption
*---------------*

*Main Paper Figure

	grc1leg 	"$dir/figures/temp/Sigma Convergence/Summary - All Resources"						///
					"$dir/figures/temp/Sigma Convergence/Summary - All Resources - Consumption"	///
					,  cols(1)   altshrink  imargin(vsmall) 
					
		graph export "$dir/figures/Figure 2 - Sigma Convergence.png", replace
					
					
*Appendix - Sigma Convergence by Resource Type

	grc1leg 	"$dir/figures/temp/Sigma Convergence/Summary - Resources by Type"				///
					"$dir/figures/temp/Sigma Convergence/Summary - Resources by Type - Consumption"	///
					,  cols(1)   iscale(.5) 
					
		graph export "$dir/figures/Appendix Figure 2 - Sigma Convergence.png", replace
