*Table 1: Summary Statistics
* Also includes summary statistics for Appendix Table A4. 

	use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear
	
* --------------------
* Panel A: Country Characteristics
* --------------------
	
	tab energyendowment
	tab oecd
	tab energyendowment if oecd==1
	tab oilendowed if oecd==1
	tab gasendowed if oecd==1
	tab coalendowed if oecd==1

	*Landlocked
	tab landlock
	tab landlock if energyendowment==1
	tab landlock if oilendowed==1
	tab landlock if gasendowed==1
	tab landlock if coalendowed==1
	tab landlock if energyendowment==0

	*Africa
	tab africa
	tab africa if energyendowment==1
	tab africa if oilendowed==1
	tab africa if gasendowed==1
	tab africa if coalendowed==1
	tab africa if energyendowment==0

	*Asia
	tab asia
	tab asia if energyendowment==1
	tab asia if oilendowed==1
	tab asia if gasendowed==1
	tab asia if coalendowed==1
	tab asia if energyendowment==0

	*Other Continent
	tab other
	tab other if energyendowment==1
	tab other if oilendowed==1
	tab other if gasendowed==1
	tab other if coalendowed==1
	tab other if energyendowment==0	
	
	
* --------------------
* Panel B: Resource Endowments
* --------------------

*See Endowments_Summary.xlsx

* --------------------
* Panel C: Economic Growth
* --------------------

	*GDP Per Capita
	sum gdp_pc7074
	sum gdp_pc1014
	
	sum gdp_pc7074 if energyendowment==1
	sum gdp_pc1014 if energyendowment==1
	
	sum gdp_pc7074 if oilendowed==1
	sum gdp_pc1014 if oilendowed==1

	sum gdp_pc7074 if gasendowed==1
	sum gdp_pc1014 if gasendowed==1

	sum gdp_pc7074 if coalendowed==1
	sum gdp_pc1014 if coalendowed==1

	sum gdp_pc7074 if energyendowment==0
	sum gdp_pc1014 if energyendowment==0
	
	*GDP Per Capita Growth Rate
	sum avggrowthrate_40yr
	sum avggrowthrate_40yr if energyendowment==1
	sum avggrowthrate_40yr if oilendowed==1
	sum avggrowthrate_40yr if gasendowed==1
	sum avggrowthrate_40yr if coalendowed==1
	sum avggrowthrate_40yr if energyendowment==0
	
	*Consumption Per Capita
	sum consumption_pc7074
	sum consumption_pc1014
	
	sum consumption_pc7074 if energyendowment==1
	sum consumption_pc1014 if energyendowment==1
	
	sum consumption_pc7074 if oilendowed==1
	sum consumption_pc1014 if oilendowed==1

	sum consumption_pc7074 if gasendowed==1
	sum consumption_pc1014 if gasendowed==1

	sum consumption_pc7074 if coalendowed==1
	sum consumption_pc1014 if coalendowed==1

	sum consumption_pc7074 if energyendowment==0
	sum consumption_pc1014 if energyendowment==0
	
	*Consumption Per Capita Growth Rate
	sum cavggrowthrate_40yr
	sum cavggrowthrate_40yr if energyendowment==1
	sum cavggrowthrate_40yr if oilendowed==1
	sum cavggrowthrate_40yr if gasendowed==1
	sum cavggrowthrate_40yr if coalendowed==1
	sum cavggrowthrate_40yr if energyendowment==0

	
* --------------------
* Panel D: Growth Components
* --------------------	
	preserve
		drop if g_y7074==. |  g_k7074==. |  g_hc7074==. |  g_tfp7074==. 	//Smaller sample due to missing data for some of these variables.  
		
		gen g_y_all = ( g_y7074 + g_y7579 + g_y8084 + g_y8589 + g_y9094 + g_y9599 + g_y0004 + g_y0509 + g_y1014 ) / 9
		gen g_k_all = ( g_k7074 + g_k7579 + g_k8084 + g_k8589 + g_k9094 + g_k9599 + g_k0004 + g_k0509 + g_k1014 ) / 9
		gen g_hc_all = ( g_hc7074 + g_hc7579 + g_hc8084 + g_hc8589 + g_hc9094 + g_hc9599 + g_hc0004 + g_hc0509 + g_hc1014 ) / 9
		gen g_tfp_all = ( g_tfp7074 + g_tfp7579 + g_tfp8084 + g_tfp8589 + g_tfp9094 + g_tfp9599 + g_tfp0004 + g_tfp0509 + g_tfp1014 ) / 9
	
		*Output Per Worker Growth
		sum g_y_all
		sum g_y_all if energyendowment==1
		sum g_y_all if oilendowed==1
		sum g_y_all if gasendowed==1
		sum g_y_all if coalendowed==1
		sum g_y_all if energyendowment==0
	
		*Capital Per Worker Growth
		sum g_k_all
		sum g_k_all if energyendowment==1
		sum g_k_all if oilendowed==1
		sum g_k_all if gasendowed==1
		sum g_k_all if coalendowed==1
		sum g_k_all if energyendowment==0
		
		*Human Capital
		sum g_hc_all
		sum g_hc_all if energyendowment==1
		sum g_hc_all if oilendowed==1
		sum g_hc_all if gasendowed==1
		sum g_hc_all if coalendowed==1
		sum g_hc_all if energyendowment==0
		
		*TFP
		sum g_tfp_all
		sum g_tfp_all if energyendowment==1
		sum g_tfp_all if oilendowed==1
		sum g_tfp_all if gasendowed==1
		sum g_tfp_all if coalendowed==1
		sum g_tfp_all if energyendowment==0	
	
	restore
	
	
* --------------------
* Panel E: Control Variables
* --------------------	
	
	* Absolute Value of Latitude
	sum lat_abst
	sum lat_abst if energyendowment==1
	sum lat_abst if oilendowed==1
	sum lat_abst if gasendowed==1
	sum lat_abst if coalendowed==1
	sum lat_abst if energyendowment==0

	*Protection Against Risk of Expropriation
	sum avexpr
	sum avexpr if energyendowment==1
	sum avexpr if oilendowed==1
	sum avexpr if gasendowed==1
	sum avexpr if coalendowed==1
	sum avexpr if energyendowment==0
	
	*Capital Stock
	sum capitalstock7074
	sum capitalstock7074 if energyendowment==1
	sum capitalstock7074 if oilendowed==1
	sum capitalstock7074 if gasendowed==1
	sum capitalstock7074 if coalendowed==1
	sum capitalstock7074 if energyendowment==0

	*Human Capital
	sum hc7074
	sum hc7074 if energyendowment==1
	sum hc7074 if oilendowed==1
	sum hc7074 if gasendowed==1
	sum hc7074 if coalendowed==1
	sum hc7074 if energyendowment==0


		
	
