*Table 2 - Beta Convergence Test
* Also creates Figure 1 graphs. 

* --------------------
* Panel A: GDP Per Capita
* --------------------
use "$dir/Oliver Upton - EJ 2022 - Cross Section.dta", clear		
	
	replace gdp_pc7074 = ln(gdp_pc7074)
		label var gdp_pc7074 "Log Real GDP per Capita - 1970-1974"
	
	*Traditional Convergence Test with All Countries
	reg  avggrowthrate_40yr  gdp_pc7074, robust
	reg  avggrowthrate_40yr  gdp_pc7074 $controls , robust
		
	twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 							///
		(lfit avggrowthrate_40yr  gdp_pc7074), 									///
		title("Full Sample") 													///
		ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off) xlabel(, grid gmax) xtitle("")
	
	graph save "$dir/figures/temp/Traditional Convergence Test", replace
	
	*Conditional Convergence Test - Energy Endowed Countries only.
	preserve
		keep if energyendowment==1
	 
		reg  avggrowthrate_40yr  gdp_pc7074 , robust
		reg  avggrowthrate_40yr  gdp_pc7074 $controls , robust
					
		twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 	///
			(lfit avggrowthrate_40yr  gdp_pc7074), 													///
			title("Energy-Endowed")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
		
		graph save "$dir/figures/temp/Conditional Convergence Test - Energy Endowed", replace
	restore	
	
	*Convergence Test - No Energy Endowment. 
	preserve
		keep if energyendowment==0
	
		reg avggrowthrate_40yr  gdp_pc7074 , robust
		reg avggrowthrate_40yr  gdp_pc7074 $controls , robust
					
		twoway (scatter avggrowthrate_40yr  gdp_pc7074  ) 	///
		(lfit avggrowthrate_40yr  gdp_pc7074), 													///
		title("Non-Energy-Endowed")																///
		ylabel( 0 "0%" 10 "10%"  20 "20%"  )legend(off)	 xlabel(, grid gmax)   xtitle("")
			
		graph save "$dir/figures/temp/Conditional Convergence Test - No Energy Endowed", replace
	restore			
	
	* Figure 1(a) - Beta Convergence Graphs - GDP Per Capita
	*Beta Convergence Combined - GDP
	graph combine "$dir/figures/temp/Traditional Convergence Test"							///
		"$dir/figures/temp/Conditional Convergence Test - Energy Endowed"					///
		"$dir/figures/temp/Conditional Convergence Test - No Energy Endowed"				///
		, ycommon xcommon 																	///
		l1title("Average Annual Growth Rate")  b1title("Log Real GDP Per Capita 1970-1974") ///
		rows(1)   ysize(1.5)  xsize(4.5)
	
	graph export "$dir/figures/Figure 1a - Beta Convergence - GDP Per Capita.png", replace	
	
* --------------------
* Panel B: Consumption Per Capita
* --------------------
	
	replace consumption_pc7074 = ln(consumption_pc7074)
		label var consumption_pc7074 "Log Real Consumption per Capita - 1970-1974"
	
	*Traditional Convergence Test with All Countries
	reg  cavggrowthrate_40yr  consumption_pc7074 , robust
	reg  cavggrowthrate_40yr  consumption_pc7074 $controls , robust
		
	twoway (scatter cavggrowthrate_40yr  consumption_pc7074 ) 					///
		(lfit cavggrowthrate_40yr  consumption_pc7074), 						///
		title("Full Sample") 													///
		ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
	
	graph save "$dir/figures/temp/Traditional Convergence Test - Consumption", replace

	*Conditional Convergence Test - Any Energy Endowment. 
	preserve
		keep if energyendowment==1
		 
		reg cavggrowthrate_40yr  consumption_pc7074 , robust
		reg cavggrowthrate_40yr  consumption_pc7074 $controls , robust
			
		twoway (scatter cavggrowthrate_40yr  consumption_pc7074 ) 	///
			(lfit cavggrowthrate_40yr  consumption_pc7074), 													///
			title("Energy-Endowed")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
			
		graph save "$dir/figures/temp/Conditional Convergence Test - Consumption - Energy Endowed", replace
	restore				
	
	*Convergence Test - No Energy Endowment. 
	preserve
		keep if energyendowment==0
		
		reg  cavggrowthrate_40yr  consumption_pc7074 , robust
		reg  cavggrowthrate_40yr  consumption_pc7074 $controls , robust
			
		twoway (scatter cavggrowthrate_40yr  consumption_pc7074  ) 	///
			(lfit cavggrowthrate_40yr  consumption_pc7074 ), 													///
			title("Non-Energy-Endowed")																///
			ylabel( 0 "0%" 10 "10%"  20 "20%"  ) legend(off)	 xlabel(, grid gmax)   xtitle("")
			
		graph save "$dir/figures/temp/Conditional Convergence Test - Consumption - No Energy Endowed", replace
	restore			
	
	* Figure 1(b) - Beta Convergence Graphs - Consumption Per Capita
	graph combine "$dir/figures/temp/Traditional Convergence Test - Consumption"					///
		"$dir/figures/temp/Conditional Convergence Test - Consumption - Energy Endowed"					///
		"$dir/figures/temp/Conditional Convergence Test - Consumption - No Energy Endowed"				///
		, ycommon xcommon																					///
		l1title("Average Annual Growth Rate")  b1title("Log Real Consumption Per Capita 1970-1974") 	///
		rows(1)   ysize(1.5)  xsize(4.5)	
	
	graph export "$dir/figures/Figure 1b - Beta Convergence - Consumption Per Capita.png", replace	
	
	
